@@ -26,7 +26,6 @@ setClass(Class = "gergm",
            observed_simulated_t_test = "data.frame",
            console_output = "character",
            print_output = "logical",
-           is_correlation_network = "logical",
            directed_network = "logical",
            simulation_only = "logical",
            thresholds = "numeric",
@@ -42,7 +41,39 @@ setClass(Class = "gergm",
            thin = "numeric",
            burnin = "numeric",
            MPLE_gain_factor = "numeric",
-           simulated_statistics_for_GOF = "data.frame"
+           simulated_statistics_for_GOF = "data.frame",
+           hessians = "list",
+           standard_errors = "list",
+           theta_grid_optimization_list = "list",
+           using_grid_optimization = "logical",
+           mu = "numeric",
+           phi = "numeric",
+           weighted_MPLE = "logical",
+           fine_grained_pv_optimization = "logical",
+           parallel = "logical",
+           parallel_statistic_calculation = "logical",
+           cores = "numeric",
+           use_stochastic_MH = "logical",
+           stochastic_MH_proportion = "numeric",
+           endogenous_statistic_node_sets = "list",
+           non_base_statistic_indicator = "numeric",
+           legacy_statistics  = "numeric",
+           legacy_alphas  = "numeric",
+           legacy_thetas = "data.frame",
+           legacy_thresholds = "numeric",
+           use_legacy_MH_sampler = "logical",
+           theta_names = "character",
+           possible_endogenous_statistic_indices = "numeric",
+           statistic_auxiliary_data = "list",
+           full_theta_names = "character",
+           covariate_terms_only = "logical",
+           simulated_bounded_networks_for_GOF = "array",
+           additional_stats = "list",
+           slackr_integration_list = "list",
+           using_slackr_integration = "logical",
+           start_time = "character",
+           end_time = "character",
+           elapsed_time = "character"
          ),
          validity = function(object) {
            if (!"matrix" %in% class(object@network) & is.null(object@network)
